// ==============================================================
//                 ORBITER MODULE: MBA
//                  Part of the ORBITER SDK
//          Copyright (C) 2002-2004 Martin Schweiger
//                   All rights reserved
//
// MBA.cpp
// Control module for MBA vessel class
//
// Notes:
// This is an example for a "minimal" vessel implementation which
// only overloads the clbkSetClassCaps method to define vessel
// capabilities and otherwise uses the default VESSEL class
// behaviour.
// ==============================================================

#ifndef __MBA_H
#define __MBA_H

#include "resource.h"


#include "orbitersdk.h"
#include "UMmuSDK.h"

// Interface for derived vessel class: QJBStar
// ==========================================================

class MBA: public VESSEL2 {
public:
    MBA (OBJHANDLE hObj, int fmodel);
	void clbkSaveState(FILEHANDLE scn);
       void clbkPostCreation (void);
	void clbkSetClassCaps (FILEHANDLE cfg);
	void clbkLoadStateEx (FILEHANDLE scn, void *status);
	int clbkConsumeBufferedKey(DWORD key, bool down, char *kstate);
	void clbkVisualCreated (VISHANDLE vis, int refcount);
 	void DefineAnimations(void); 
	void clbkVisualDestroyed (VISHANDLE vis, int refcount);
	void clbkPostStep (double simtt, double simdt, double mjd);
	void clbkFocusChanged(bool getfocus,OBJHANDLE hNewVessel,OBJHANDLE hOldVessel);
enum HATCHStatus { HATCH_UP, HATCH_DOWN, HATCH_RAISING, HATCH_LOWERING } CARGOBAY_status,DD1_status,DD2_status,DD3_status,DD4_status,DD0_status,LP1D_status,LP2D_status,LP3D_status,LP4D_status,LP5D_status,LP5_status,LP1_status,LP2_status,LP3_status,LP4_status,ULP1D_status,ULP2D_status,ULP3D_status,ULP4D_status,ULP5D_status,DD5_status,DD6_status;
  void MBA::SelectCockpitView (int CAM); 
void AttachCargo();
    void DetachCargo();  
    void HUD_Text(const HUDPAINTSPEC* pHPS, HDC hdc);
    void RevertDOCKdoor();
     void RevertDOCK1door();
	     void clbkDrawHUD(int iMode, const HUDPAINTSPEC* pHPS, HDC hdc);
 void RevertDD0();
  void RevertDD1();
   void RevertDD2();
    void RevertDD3();
	 void RevertDD4();
   void RevertLP();  
 void RevertLPdoor(); 
 void RevertCARGOBAY();
	void SetUMMUAirlockPos (void);
// UMMU 1.5 DECLARATION
	UMMUCREWMANAGMENT Crew;
	void clbkSetClassCaps_UMMu(void);	// our special SetClassCapfunction added for more readability
	int SelectedUmmuMember;				// for the SDK demo, select the member to eva
	int UmmuSdKInitReturnCode;			// to display init message to user (in case Ummu isn't installed on Orbiter)

	// our custom oapiDebugString() function (an orbiter function that display debug text at bottom of screen)
	// Our custom function display only message if we have focus. The variables below is used by this function.
	// don't forget if you use such text interface in your vessel that you must initialise the variables
	// in set class cap and do also some code in clbkFocusChanged
	char cOurMessage[1000];
	char *SendFocusScreenMessage();	

	// If you want to use standard ID function see bottom of UMmuExample.cpp
	int EvaCrewMemberWithStandardSpacesuit(char* CrewName);	
	int  i,oneTimeOnly;
TEXTMETRIC tm;
MGROUP_TRANSFORM *CARGOBAYdoor, *CARGOBAYdoor1;
private:
UINT anim_DD1;
UINT anim_DD2;
UINT anim_DD3;
UINT anim_DD4;
UINT anim_DD0;
UINT anim_DD1a;
UINT anim_DD2a;
UINT anim_DD3a;
UINT anim_DD4a;
UINT anim_DD0a;
UINT anim_LP5;
UINT anim_LP1;
UINT anim_LP2;
UINT anim_LP3;
UINT anim_LP4;
UINT anim_LP1DOOR1;
UINT anim_LP1DOOR2;
UINT anim_LP2DOOR1;
UINT anim_LP2DOOR2;
UINT anim_LP3DOOR1;
UINT anim_LP3DOOR2;
UINT anim_LP4DOOR1;
UINT anim_LP4DOOR2;
UINT anim_LP5DOOR1;
UINT anim_LP5DOOR2;
UINT anim_LP1DOOR1a;
UINT anim_LP1DOOR2a;
UINT anim_LP2DOOR1a;
UINT anim_LP2DOOR2a;
UINT anim_LP3DOOR1a;
UINT anim_LP3DOOR2a;
UINT anim_LP4DOOR1a;
UINT anim_LP4DOOR2a;
UINT anim_LP5DOOR1a;
UINT anim_LP5DOOR2a;
UINT anim_ULP1DOOR2;
UINT anim_ULP1DOOR1;
UINT anim_ULP2DOOR2;
UINT anim_ULP2DOOR1;
UINT anim_ULP3DOOR2;
UINT anim_ULP3DOOR1;
UINT anim_ULP4DOOR2;
UINT anim_ULP4DOOR1;
UINT anim_ULP5DOOR2;
UINT anim_ULP5DOOR1;
UINT anim_CARGODOOR1LEFT;
UINT anim_CARGODOOR1RIGHT;
UINT anim_CARGODOOR2LEFT;
UINT anim_CARGODOOR2RIGHT;
UINT anim_CARGODOOR1ALEFT;
UINT anim_CARGODOOR1ARIGHT;
UINT anim_CARGODOOR2ALEFT;
UINT anim_CARGODOOR2ARIGHT;
UINT anim_CARGOBAYDOOR1;
UINT anim_CARGOBAYDOOR;
UINT anim_CARGOBAYDOORA;
int whichap;
int CAM;
int  pit, whichone, do_attach, first_time, f8,liftpad;
int APSel;
double apd;
int MARSBASEID;
double ULP1D_proc;
double ULP2D_proc;
double ULP3D_proc;
double ULP4D_proc;
double ULP5D_proc;
double LP1D_proc;
double LP2D_proc;
double LP3D_proc;
double LP4D_proc;
double LP5D_proc;
double DD1_proc;
double DD2_proc;
double DD3_proc;
double DD4_proc;
double DD0_proc;
double DD5_proc;
double DD6_proc;
double CARGOBAY_proc;


double LP5_proc;
double LP1_proc;
double LP2_proc;
double LP3_proc;
double LP4_proc;

double vsAirSpeed;
double aspeed;
double LP1_INT_POS;
double LP2_INT_POS;
double LP3_INT_POS;
double LP4_INT_POS;
double LP5_INT_POS;



double BAYFACTOR;
double LIFT_SPEED, ELEV_SPEED;
double MAX_GRAP_DIST;
int iActiveDockNumber,doorselected;
int cl;
int i2;
double iop;

ATTACHMENTHANDLE LP1,LP2,LP3,LP4,LP5;
BEACONLIGHTSPEC beacon[7];
BEACONLIGHTSPEC APbeacon[7];

VECTOR3 LP1_pos;
VECTOR3 LP2_pos;
VECTOR3 LP3_pos;
VECTOR3 LP4_pos;
VECTOR3 LP5_pos;
double pit2;









OBJHANDLE MBA_handle;
ATTACHMENTHANDLE hAtt2;
VECTOR3 APbeaconpos[6];

};

typedef struct {
	HINSTANCE hDLL;
	HFONT font[2];
	DWORD col[4];
	HBRUSH brush[4];
	HPEN pen[2];
} GDIParams;
#endif // !__MBA_H
